"""Version information for xAgent package."""

import importlib.metadata

__version__ = importlib.metadata.version("myxagent")
__author__ = "xAgent Team"
__email__ = "zhangjun310@live.com"
__description__ = "Multi-Modal AI Agent System"
